==> smoothcreeper-1.0.0%2Bmc1.21.10-sources.jar: archives/tater/smoothcreeper/SmoothCreeper.java <==
package archives.tater.smoothcreeper;

import net.fabricmc.api.ModInitializer;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_7924;
import net.minecraft.class_9304;
import net.minecraft.class_9334;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.function.Function;

import static net.minecraft.class_156.method_34865;

public class SmoothCreeper implements ModInitializer {
	public static final String MOD_ID = "smoothcreeper";

	// This logger is used to write text to the console and the log file.
	// It is considered best practice to use your mod id as the logger's name.
	// That way, it's clear which mod wrote info, warnings, and errors.
	public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final Function<class_1937, class_1799> TOOL = method_34866(level -> {
        var stack = class_1802.field_8377.method_7854();
        var enchantments = new class_9304.class_9305(class_9304.field_49385);
        enchantments.method_57547(level.method_30349().method_30530(class_7924.field_41265).method_46747(class_1893.field_9099), 1);
        stack.method_57379(class_9334.field_49633, enchantments.method_57549());
        return stack;
    });

	@Override
	public void onInitialize() {
		// This code runs as soon as Minecraft is in a mod-load-ready state.
		// However, some things (like resources) may still be uninitialized.
		// Proceed with mild caution.


	}
}

==> smoothcreeper-1.0.1%2Bmc1.21.1-sources.jar: archives/tater/smoothcreeper/SmoothCreeper.java <==
package archives.tater.smoothcreeper;

import net.fabricmc.api.ModInitializer;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1893;
import net.minecraft.class_5455;
import net.minecraft.class_7924;
import net.minecraft.class_9304;
import net.minecraft.class_9334;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.WeakHashMap;
import java.util.function.Function;

public class SmoothCreeper implements ModInitializer {
	public static final String MOD_ID = "smoothcreeper";

	// This logger is used to write text to the console and the log file.
	// It is considered best practice to use your mod id as the logger's name.
	// That way, it's clear which mod wrote info, warnings, and errors.
	public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    private static <T, R> Function<T, R> weakMemoize(Function<T, R> transform) {
        var cache = new WeakHashMap<T, R>();
        return t -> cache.computeIfAbsent(t, transform);
    }

    public static final Function<class_5455, class_1799> TOOL = weakMemoize(registryAccess -> {
        var stack = class_1802.field_8377.method_7854();
        var enchantments = new class_9304.class_9305(class_9304.field_49385);
        enchantments.method_57547(registryAccess.method_46762(class_7924.field_41265).method_46747(class_1893.field_9099), 1);
        stack.method_57379(class_9334.field_49633, enchantments.method_57549());
        return stack;
    });

	@Override
	public void onInitialize() {
		// This code runs as soon as Minecraft is in a mod-load-ready state.
		// However, some things (like resources) may still be uninitialized.
		// Proceed with mild caution.


	}
}
